==> haskell-extra-1.6.18-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: extra
version: 1.6.18
id: extra-1.6.18-Hvb5V9crxyzC6wVibsyssz
key: extra-1.6.18-Hvb5V9crxyzC6wVibsyssz
license: BSD-3-Clause
copyright: Neil Mitchell 2014-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/extra#readme
synopsis: Extra functions I use.
description:
    A library of extra functions for the standard Haskell libraries. Most functions are simple additions, filling out missing functionality. A few functions are available in later versions of GHC, but this package makes them available back to GHC 7.2.
    .
    The module "Extra" documents all functions provided by this library. Modules such as "Data.List.Extra" provide extra functions over "Data.List" and also reexport "Data.List". Users are recommended to replace "Data.List" imports with "Data.List.Extra" if they need the extra functionality.
category: Development
abi: e1bec1c84b860b56b5bf26e9fc9b49f7
exposed: True
exposed-modules:
    Control.Concurrent.Extra Control.Exception.Extra
    Control.Monad.Extra Data.Either.Extra Data.IORef.Extra
    Data.List.Extra Data.List.NonEmpty.Extra Data.Tuple.Extra
    Data.Typeable.Extra Data.Version.Extra Extra Numeric.Extra
    System.Directory.Extra System.Environment.Extra System.IO.Extra
    System.Info.Extra System.Process.Extra System.Time.Extra
    Text.Read.Extra
hidden-modules: Partial
import-dirs: /usr/lib/ghc-8.6.5/site-local/extra-1.6.18
library-dirs: /usr/lib/ghc-8.6.5/site-local/extra-1.6.18
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/extra-1.6.18
hs-libraries: HSextra-1.6.18-Hvb5V9crxyzC6wVibsyssz
depends:
    base-4.12.0.0 clock-0.8-H1S1zDefxirImaRbI6ITNv directory-1.3.3.0
    filepath-1.4.2.1 process-1.6.5.0 time-1.8.0.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-extra/html/extra.haddock
haddock-html: /usr/share/doc/haskell-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-extra-1.6.18-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: extra
version: 1.6.18
id: extra-1.6.18-C8rpwMjbnSZ7dBHvBfZVKs
key: extra-1.6.18-C8rpwMjbnSZ7dBHvBfZVKs
license: BSD-3-Clause
copyright: Neil Mitchell 2014-2019
maintainer: Neil Mitchell <ndmitchell@gmail.com>
author: Neil Mitchell <ndmitchell@gmail.com>
homepage: https://github.com/ndmitchell/extra#readme
synopsis: Extra functions I use.
description:
    A library of extra functions for the standard Haskell libraries. Most functions are simple additions, filling out missing functionality. A few functions are available in later versions of GHC, but this package makes them available back to GHC 7.2.
    .
    The module "Extra" documents all functions provided by this library. Modules such as "Data.List.Extra" provide extra functions over "Data.List" and also reexport "Data.List". Users are recommended to replace "Data.List" imports with "Data.List.Extra" if they need the extra functionality.
category: Development
abi: 7d355a435b11438f87be5f33405799d0
exposed: True
exposed-modules:
    Control.Concurrent.Extra Control.Exception.Extra
    Control.Monad.Extra Data.Either.Extra Data.IORef.Extra
    Data.List.Extra Data.List.NonEmpty.Extra Data.Tuple.Extra
    Data.Typeable.Extra Data.Version.Extra Extra Numeric.Extra
    System.Directory.Extra System.Environment.Extra System.IO.Extra
    System.Info.Extra System.Process.Extra System.Time.Extra
    Text.Read.Extra
hidden-modules: Partial
import-dirs: /usr/lib/ghc-8.6.5/site-local/extra-1.6.18
library-dirs: /usr/lib/ghc-8.6.5/site-local/extra-1.6.18
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/extra-1.6.18
hs-libraries: HSextra-1.6.18-C8rpwMjbnSZ7dBHvBfZVKs
depends:
    base-4.12.0.0 clock-0.8-H1S1zDefxirImaRbI6ITNv directory-1.3.3.0
    filepath-1.4.2.1 process-1.6.5.0 time-1.8.0.2 unix-2.7.2.2
haddock-interfaces: /usr/share/doc/haskell-extra/html/extra.haddock
haddock-html: /usr/share/doc/haskell-extra/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
